@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Map v1.2.0;
+package PFT::Map v1.2.1;
 
 =encoding utf8
 
@@ -83,9 +83,10 @@ sub _resolve {
         for my $symbol ($node->symbols) {
             my $resolved = eval {
                 my @rs = $index->resolve($node, $symbol);
-                if (@rs > 1) {
+                if (@rs != 1) {
                     local $" = ', ';
-                    croak "Ambiguously resolved, matching { @rs }\n";
+                    croak @rs ? "Ambiguous resolution { @rs }"
+                              : "No matching item";
                 }
                 $rs[0]
             };
@@ -101,7 +102,7 @@ sub _resolve {
             }
             else {
                 $node->add_outlink(undef);
-                my $reason = ($@ ? $@ =~ s/\v.*//rs : undef);
+                my $reason = ($@ ? $@ =~ s/ at .*$//rs : undef);
                 $node->add_symbol_unres($symbol => $reason);
             }
         }
